/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.mgmt;

public class Rdbms extends com.mysql.grt.GrtObject {

    protected Rdbms() {
    }

    public Rdbms(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new RdbmsDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new RdbmsDataGlobal((String) obj);
        }
    }

    public String getCaption() {
        return ((RdbmsData) data).getCaption();
    }

    public String setCaption(String caption) {
        ((RdbmsData) data).setCaption(caption);

        return getCaption();
    }

    public String getDatabaseObjectPackage() {
        return ((RdbmsData) data).getDatabaseObjectPackage();
    }

    public String setDatabaseObjectPackage(String databaseObjectPackage) {
        ((RdbmsData) data).setDatabaseObjectPackage(databaseObjectPackage);

        return getDatabaseObjectPackage();
    }

    public com.mysql.grt.db.mgmt.DriverList getDrivers() {
        return ((RdbmsData) data).getDrivers();
    }

    public com.mysql.grt.db.mgmt.DriverList setDrivers(com.mysql.grt.db.mgmt.DriverList drivers) {
        ((RdbmsData) data).setDrivers(drivers);

        return getDrivers();
    }

    public com.mysql.grt.db.SimpleDatatypeList getSimpleDatatypes() {
        return ((RdbmsData) data).getSimpleDatatypes();
    }

    public com.mysql.grt.db.SimpleDatatypeList setSimpleDatatypes(com.mysql.grt.db.SimpleDatatypeList simpleDatatypes) {
        ((RdbmsData) data).setSimpleDatatypes(simpleDatatypes);

        return getSimpleDatatypes();
    }

    public com.mysql.grt.db.CharacterSetList getCharacterSets() {
        return ((RdbmsData) data).getCharacterSets();
    }

    public com.mysql.grt.db.CharacterSetList setCharacterSets(com.mysql.grt.db.CharacterSetList characterSets) {
        ((RdbmsData) data).setCharacterSets(characterSets);

        return getCharacterSets();
    }

    public com.mysql.grt.db.mgmt.Driver getDefaultDriver() {
        return ((RdbmsData) data).getDefaultDriver();
    }

    public com.mysql.grt.db.mgmt.Driver setDefaultDriver(com.mysql.grt.db.mgmt.Driver defaultDriver) {
        ((RdbmsData) data).setDefaultDriver(defaultDriver);

        return getDefaultDriver();
    }

    public String getDefaultDriverById() {
        return ((RdbmsData) data).getDefaultDriverById();
    }

    public void setDefaultDriverById(String defaultDriver) {
        ((RdbmsData) data).setDefaultDriverById(defaultDriver);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            if (getCaption() != null) {
                xml.append("<value type=\"string\" key=\"caption\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getCaption()) + "</value>\n");
            }

            if (getDatabaseObjectPackage() != null) {
                xml.append("<value type=\"string\" key=\"databaseObjectPackage\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDatabaseObjectPackage()) + "</value>\n");
            }

            if (getDrivers() != null) {
                getDrivers().getGrtXml(xml, " key=\"drivers\"");
            }

            if (getSimpleDatatypes() != null) {
                getSimpleDatatypes().getGrtXml(xml, " key=\"simpleDatatypes\"");
            }

            if (getCharacterSets() != null) {
                getCharacterSets().getGrtXml(xml, " key=\"characterSets\"");
            }

            if (getDefaultDriver() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"defaultDriver\">"
                        + getDefaultDriverById() + "</value>\n");
            }

        return xml;
    }
}
