/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.oracle;

public class Routine extends com.mysql.grt.db.Routine {

    protected Routine() {
    }

    public Routine(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new RoutineDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new RoutineDataGlobal((String) obj);
        }
    }

    public int getAggregate() {
        return ((RoutineData) data).getAggregate();
    }

    public int setAggregate(int aggregate) {
        ((RoutineData) data).setAggregate(aggregate);

        return getAggregate();
    }

    public int getPipelined() {
        return ((RoutineData) data).getPipelined();
    }

    public int setPipelined(int pipelined) {
        ((RoutineData) data).setPipelined(pipelined);

        return getPipelined();
    }

    public int getParallel() {
        return ((RoutineData) data).getParallel();
    }

    public int setParallel(int parallel) {
        ((RoutineData) data).setParallel(parallel);

        return getParallel();
    }

    public String getImplTypeOwner() {
        return ((RoutineData) data).getImplTypeOwner();
    }

    public String setImplTypeOwner(String implTypeOwner) {
        ((RoutineData) data).setImplTypeOwner(implTypeOwner);

        return getImplTypeOwner();
    }

    public String getImplTypeName() {
        return ((RoutineData) data).getImplTypeName();
    }

    public String setImplTypeName(String implTypeName) {
        ((RoutineData) data).setImplTypeName(implTypeName);

        return getImplTypeName();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"aggregate\">"
                    + Integer.toString(getAggregate()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"pipelined\">"
                    + Integer.toString(getPipelined()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"parallel\">"
                    + Integer.toString(getParallel()) + "</value>\n");

            if (getImplTypeOwner() != null) {
                xml.append("<value type=\"string\" key=\"implTypeOwner\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getImplTypeOwner()) + "</value>\n");
            }

            if (getImplTypeName() != null) {
                xml.append("<value type=\"string\" key=\"implTypeName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getImplTypeName()) + "</value>\n");
            }

        return xml;
    }
}
