/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.query;

public class Query extends com.mysql.grt.GrtObject {

    protected Query() {
    }

    public Query(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new QueryDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new QueryDataGlobal((String) obj);
        }
    }

    public String getSql() {
        return ((QueryData) data).getSql();
    }

    public String setSql(String sql) {
        ((QueryData) data).setSql(sql);

        return getSql();
    }

    public String getModuleName() {
        return ((QueryData) data).getModuleName();
    }

    public String setModuleName(String moduleName) {
        ((QueryData) data).setModuleName(moduleName);

        return getModuleName();
    }

    public com.mysql.grt.db.query.QueryParameterList getParams() {
        return ((QueryData) data).getParams();
    }

    public com.mysql.grt.db.query.QueryParameterList setParams(com.mysql.grt.db.query.QueryParameterList params) {
        ((QueryData) data).setParams(params);

        return getParams();
    }

    public com.mysql.grt.db.mgmt.Connection getConnection() {
        return ((QueryData) data).getConnection();
    }

    public com.mysql.grt.db.mgmt.Connection setConnection(com.mysql.grt.db.mgmt.Connection connection) {
        ((QueryData) data).setConnection(connection);

        return getConnection();
    }

    public String getConnectionById() {
        return ((QueryData) data).getConnectionById();
    }

    public void setConnectionById(String connection) {
        ((QueryData) data).setConnectionById(connection);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            if (getSql() != null) {
                xml.append("<value type=\"string\" key=\"sql\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getSql()) + "</value>\n");
            }

            if (getModuleName() != null) {
                xml.append("<value type=\"string\" key=\"moduleName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getModuleName()) + "</value>\n");
            }

            if (getParams() != null) {
                getParams().getGrtXml(xml, " key=\"params\"");
            }

            if (getConnection() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"connection\">"
                        + getConnectionById() + "</value>\n");
            }

        return xml;
    }
}
